May 5, 2019.
Cambridge, MA.

# SayTeX Package Progress

The first three layers, as outlined in blog post 3, have been implemented. The next 5 layers are remaining, but should hopefully be relatively simple to implement since we have a nice object-oriented structure now.

I am still not certain that the CFG is going to be a good idea. Honestly, since I don't have much time and it is limited in scope anyway, I think I will decide not to implement that layer as a CFG, but rather take my old naive implementation of it. It is not ideal, but it decreases my dependencies while not removing any crucial functionality. In the future, considering that I now know a fair amount about defining context-free grammars and what they can be used for, it is definitely possible that I will revisit the project and implement it.

Now: do the remaining 5 layers.

I have now implemented the two arguably most important layers. The "over" layer is also important, but I still don't know how to do that, so I am ignoring it for now.

Rather, I want to focus on packaging this as nicely as possible, now, because it is functional and this can be seen as an early release.

- Build an early version of the docs which can be hosted on readthedocs.
- Release version 0.1.0 to pypi.
- Release the same version on github.
- Make demo website use the 